@@ -81,7 +81,6 @@ static void move_current_tab_to_another_notebook  (PlumaNotebook  *src,
 
 /* Local variables */
 static GdkCursor *cursor = NULL;
-static gboolean leftdown = FALSE;
 
 /* Signals */
 enum
@@ -390,8 +389,6 @@ static void
 drag_start (PlumaNotebook *notebook,
 	    guint32        time)
 {
-	if (!leftdown) return;
-
 	notebook->priv->drag_in_progress = TRUE;
 
 	/* get a new cursor, if necessary */
@@ -555,8 +552,6 @@ button_release_cb (PlumaNotebook  *notebook,
 		   GdkEventButton *event,
 		   gpointer        data)
 {
-	if (event->button == 1) leftdown = FALSE;
-
 	if (notebook->priv->drag_in_progress)
 	{
 		gint cur_page_num;
@@ -596,6 +591,9 @@ button_press_cb (PlumaNotebook  *notebook,
 		 GdkEventButton *event,
 		 gpointer        data)
 {
+	static gboolean newfile = FALSE;
+	static gint tab1click = -1;
+
 	gint tab_clicked;
 
 	if (notebook->priv->drag_in_progress)
@@ -604,13 +602,11 @@ button_press_cb (PlumaNotebook  *notebook,
 	tab_clicked = find_tab_num_at_pos (notebook,
 					   event->x_root,
 					   event->y_root);
-					   
+
 	if ((event->button == 1) && 
 	    (event->type == GDK_BUTTON_PRESS) && 
 	    (tab_clicked >= 0))
 	{
-		leftdown = TRUE;
-
 		notebook->priv->x_start = event->x_root;
 		notebook->priv->y_start = event->y_root;
 		
@@ -634,17 +630,29 @@ button_press_cb (PlumaNotebook  *notebook,
 		}
 		else
 		{
-			if (leftdown) {
-				leftdown = FALSE;
-				return TRUE;
-			}
-
 			/* Switch to the page the mouse is over, but don't consume the event */
 			gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 
 						       tab_clicked);
 		}
 	}
 
+	if (event->button == 1)
+	{
+		if (event->type == GDK_BUTTON_PRESS)
+		{
+			tab1click = gtk_notebook_get_current_page (notebook);
+			newfile = (tab_clicked == -1);
+		}
+		else if (event->type == GDK_2BUTTON_PRESS)
+		{
+			if ((tab1click != gtk_notebook_get_current_page (notebook)) ||
+			    (tab_clicked >= 0) || ((tab_clicked == -1) && (!newfile)))
+				return TRUE;
+
+			newfile = FALSE;
+		}
+	}
+
 	return FALSE;
 }
 
